DsdReader

Struct DsdReader 

pub struct DsdReader { /* private fields */ }
DSD input context for reading DSD audio data from various sources.

Implementations

Source

impl DsdReader

pub fn dsd_rate(&self) -> i32

pub fn channels_num(&self) -> usize

pub fn std_in(&self) -> bool

pub fn tag(&self) -> &Option<Tag>

pub fn file_name(&self) -> &OsString

pub fn audio_length(&self) -> u64

pub fn block_size(&self) -> u32

pub fn parent_path(&self) -> &Option<PathBuf>

pub fn in_path(&self) -> &Option<PathBuf>

pub fn new( in_path: Option<PathBuf>, format: FmtType, endianness: Endianness, dsd_rate: DsdRate, block_size: u32, channels: usize, ) -> Result<Self, Box<dyn Error>>

Construct DsdReader from stdin or a file path. Note that for container files, like DSF or DFF, you may prefer to use from_container(in_path) instead. If in_path is None, stdin is assumed. If in_path is a file containing raw DSD data, the other parameters are used to interpret the data. If in_path is a container file, the container metadata will override the other parameters.

Arguments
  • in_path - Optional path to input file. If None, stdin is used.
  • format - DSD channel format (planar or interleaved)
  • endianness - DSD bit endianness (LSB-first or MSB-first)
  • dsd_rate - DSD rate multiplier
  • block_size - Block size of each read in bytes per channel
  • channels - Number of audio channels
pub fn from_container(in_path: PathBuf) -> Result<Self, Box<dyn Error>>

Construct DsdReader from container file input (e.g. DSF, DFF)

pub fn dsd_iter(&self) -> Result<DsdIter, Box<dyn Error>>

Construct and return instance of DSD sample iterator for reading DSD data frames.